# OIDCProxyUpstreamConfig

The configuration of the upstream host and scheme.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**scheme** | **str** | The scheme defines the type of protocol to be used to access the upstream. | 
**hostname** | **str** | The hostname of the upstream server. It will be used to provision the host/authority header for requests the proxy forwards to it. | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


